Module source

Implementations for the different kinds of dependency sources.

Enums

DepPathError
Failed to resolve the dependency’s path.
PinAndFetchError
Failed to pin or fetch the source of a dependency.
PinAndFetchErrorKind
Failed to pin or fetch the source of a particular dependency source type.
Pinned
Represents the source for a package.
SourceError
Error indicating failure to construct Source from manifest dependency.

Functions

fetch_graph_id
A unique ID for a fetch pass.

Type Aliases

FetchId